#
# spec file for package lighttpd
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pkg_home %{_localstatedir}/lib/%{name}
Name:           lighttpd
Version:        1.4.37
Release:        3.4
#
%define pkg_name %{name}
%define pkg_version %{version}
%define tarball_version %{version}
#
Summary:        A Secure, Fast, Compliant, and Very Flexible Web Server
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
Url:            http://www.lighttpd.net/
Source:         %{name}_%{tarball_version}.orig.tar.xz
Source1:        %{name}.init
Source2:        %{name}.sysconfig
Source4:        lightytest.sh
Source5:        lighttpd.SuSEfirewall
Source6:        lighttpd-ssl.SuSEfirewall
Source7:        lighttpd.logrotate
Patch0:         lighttpd-1.4.13_geoip.patch
BuildRequires:  FastCGI-devel
BuildRequires:  GeoIP-devel
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  gdbm-devel
BuildRequires:  iputils
BuildRequires:  libattr-devel
BuildRequires:  libbz2-devel
BuildRequires:  libmemcache-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  mysql-devel
BuildRequires:  openldap2-devel
BuildRequires:  pcre-devel
BuildRequires:  php5-fastcgi
BuildRequires:  pkgconfig
BuildRequires:  pwdutils
BuildRequires:  sqlite-devel >= 3
BuildRequires:  zlib-devel
BuildRequires:  perl(CGI)
Requires:       spawn-fcgi
Requires(pre):  pwdutils
Requires(post): %insserv_prereq %fillup_prereq
Recommends:     logrotate
Provides:       http_daemon
Provides:       httpd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1210
BuildRequires:  gamin-devel
BuildRequires:  lua51-devel
%else
BuildRequires:  fam-devel
BuildRequires:  lua-devel
%endif

%description
Lighttpd is a secure, fast, compliant, and very flexible Web server
that has been optimized for high-performance environments. It has a
very low memory footprint compared to other Web servers and takes care
of CPU load. Its advanced feature set (FastCGI, CGI, Auth,
Output-Compression, URL-Rewriting, and more) makes lighttpd the perfect
Web server software for every server that is suffering load problems.

%package mod_cml
Summary:        CML (Cache Meta Language) module for Lighttpd
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description mod_cml
CML is a Meta language to describe the dependencies of a page at one
side and building a page from its fragments on the oth er side using
LUA.

CML (Cache Meta Language) wants to solves several problems:

* dynamic content needs caching to perform

* checking if the content is dirty inside of the application is
   usually more expensive than sending out the cached data

* a dynamic page is usually fragmented and the fragments have
   different livetimes

* the different fragements can be cached independently

%package mod_magnet
Summary:        A module to control the request handling in lighttpd
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description mod_magnet
A module to control the request handling in lighttpd.

It is the successor of mod_cml.

%package mod_mysql_vhost
Summary:        MySQL based virtual hosts (vhosts) module for Lighttpd
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description mod_mysql_vhost
With MySQL based vhosting you can put the information where to look for
a. document-root of a given host into a MySQL database.

%package mod_trigger_b4_dl
Summary:        Another anti hot-linking module for Lighttpd
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description mod_trigger_b4_dl
Anti Hotlinking:

* if user requests download-url directly the request is denied and
   he is redirected to ''deny-url'

* if user visits trigger-url before requesting download-url access
   is granted

* if user visits download-url again after trigger-timeout has run
   down to the request is denied and he is redirected  to deny-url

The storage for the trigger information is either stored locally in a
gdbm file or remotly in memcached.

%package mod_rrdtool
Summary:        Lighttpd module to feed rrdtool databases
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}
Requires:       rrdtool

%description mod_rrdtool
RRD_tool is a system to store and display time-series data (i.e.
network bandwidth, machine-room temperature, server load average).

This module feeds an rrdtool database with the traffic stats from
lighttpd.

%package mod_geoip
Summary:        A Secure, Fast, Compliant, and Very Flexible Web Server
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description mod_geoip
Lighttpd a secure, fast, compliant, and very flexible Web server that
has been optimized for high-performance environments. It has a very low
memory footprint compared to other Web servers and takes care of CPU
load.  Its advanced feature set (FastCGI, CGI, Auth,
Output-Compression, URL-Rewriting, and more) makes lighttpd the perfect
Web server software for every server that is suffering load problems.

This is just a dummy package which is not build in autobuild. see the
buildservice project server:http if you want it.

%package mod_webdav
Summary:        WebDAV module for Lighttpd
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description mod_webdav
The WebDAV module is a very minimalistic implementation of RFC 2518.
Minimalistic means that not all operations are implementated yet..

So far we have:
* PROPFIND
* OPTIONS
* MKCOL
* DELETE
* PUT
and the usual GET, POST, HEAD from HTTP/1.1..

So far mounting a webdav resource into Windows XP works and the basic
litmus tests are passed.

%prep
%setup -q -n %{pkg_name}-%{pkg_version}
%patch0

# Do not store build TIME and DATE
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -name '*.[ch]' |\
    xargs sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g"

%build
autoreconf -fvi
export CFLAGS="%{optflags} -DLDAP_DEPRECATED -W -Wmissing-prototypes -Wmissing-declarations -Wpointer-arith -Wchar-subscripts -Wformat=2 -Wbad-function-cast -std=gnu99 -fstack-protector"
%configure                      \
    --bindir=%{_sbindir}        \
    --libdir=%{_libdir}/%{name} \
    --enable-lfs                \
    --enable-ipv6               \
    --with-ldap                 \
    --with-mysql                \
    --with-openssl              \
    --with-kerberos5            \
    --with-gdbm                 \
    --with-lua                  \
    --with-memcache             \
    --with-bzip2                \
    --with-webdav-props         \
    --with-webdav-locks         \
    --with-fam                  \
    --with-attr
make %{?_smp_mflags}

%check
%if 0%{?suse_version} > 1200
export PHP="/srv/www/cgi-bin/php"
%else
export PHP="/srv/www/cgi-bin/php5"
%endif
sh -x %{SOURCE4}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
install -d -m 0755                                 \
    %{buildroot}%{pkg_home}/sockets/               \
    %{buildroot}%{_var}/cache/%{name}/compress     \
    %{buildroot}%{_var}/log/%{name}                \
    %{buildroot}%{_sysconfdir}/%{name}
#
# init script
#
install -D -m 0755 %{SOURCE1} \
    %{buildroot}%{_sysconfdir}/init.d/%{name}
ln -s -f %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
#
# sample config
#
perl -p -i.orig -e 's|^(server\.tag = ).*$|$1 "%{name} (%{version}/SuSE)"|' doc/config/lighttpd.conf
diff -ur doc/config/lighttpd.conf{.orig,} ||:
rm -vf doc/config/lighttpd.conf.orig ||:
cp -rv doc/config/* %{buildroot}%{_sysconfdir}/%{name}/
# as much as i would like to use -delete here. sles9 doesnt understand it.
find %{buildroot}%{_sysconfdir}/%{name}/ -name Makefile\* -print0 | xargs -r0 rm -fv
#
# sysconfig template
#
install -D -m 0644 %{SOURCE2} \
    %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
#
# susefirewall config file
#
install -D -m 0644 %{SOURCE5} \
    %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/lighttpd
install -D -m 0644 %{SOURCE6} \
    %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/lighttpd-ssl
#
# logrotate config
#
install -D -m 0644 %{SOURCE7} \
    %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
#
# remove the .la files. we dont need them.
#
find %{buildroot} -type f -name "*.la" -delete -print

%pre
%{_sbindir}/groupadd -r %{name} >/dev/null 2>&1 ||:
%{_sbindir}/useradd  -g %{name} -s /bin/false -r -c "user for %{name}" -d %{pkg_home} %{name} >/dev/null 2>&1 ||:

%post
%fillup_and_insserv %{name}

%preun
%stop_on_removal %{name}

%postun
%restart_on_update %{name}
%insserv_cleanup

%files
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/lighttpd*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sbindir}/*
%dir %attr(750,root,%{name}) %{_sysconfdir}/%{name}
%dir %attr(750,root,%{name}) %{_sysconfdir}/%{name}/conf.d
%dir %attr(750,root,%{name}) %{_sysconfdir}/%{name}/vhosts.d
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/lighttpd.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/modules.conf
# modules config
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/access_log.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/auth.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/cgi.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/compress.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/debug.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/dirlisting.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/evhost.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/expire.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/fastcgi.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/mime.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/mod.template
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/proxy.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/scgi.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/secdownload.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/simple_vhost.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/ssi.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/status.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/userdir.conf
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/vhosts.d/vhosts.template
# modules
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/mod_access.so
%{_libdir}/%{name}/mod_accesslog.so
%{_libdir}/%{name}/mod_alias.so
%{_libdir}/%{name}/mod_auth.so
%{_libdir}/%{name}/mod_cgi.so
%{_libdir}/%{name}/mod_compress.so
%{_libdir}/%{name}/mod_dirlisting.so
%{_libdir}/%{name}/mod_evasive.so
%{_libdir}/%{name}/mod_evhost.so
%{_libdir}/%{name}/mod_expire.so
%{_libdir}/%{name}/mod_extforward.so
%{_libdir}/%{name}/mod_fastcgi.so
%{_libdir}/%{name}/mod_flv_streaming.so
%{_libdir}/%{name}/mod_indexfile.so
%{_libdir}/%{name}/mod_proxy.so
%{_libdir}/%{name}/mod_redirect.so
%{_libdir}/%{name}/mod_rewrite.so
%{_libdir}/%{name}/mod_scgi.so
%{_libdir}/%{name}/mod_secdownload.so
%{_libdir}/%{name}/mod_setenv.so
%{_libdir}/%{name}/mod_simple_vhost.so
%{_libdir}/%{name}/mod_ssi.so
%{_libdir}/%{name}/mod_staticfile.so
%{_libdir}/%{name}/mod_status.so
%{_libdir}/%{name}/mod_userdir.so
%{_libdir}/%{name}/mod_usertrack.so
%{_mandir}/man8/*.8*
%config(noreplace) %{_sysconfdir}/init.d/%{name}
%doc AUTHORS NEWS README
#doc doc/*.dot
%doc doc/scripts/spawn-php.sh
%doc doc/outdated/accesslog.txt
%doc doc/outdated/access.txt
%doc doc/outdated/alias.txt
%doc doc/outdated/authentication.txt
%doc doc/outdated/cgi.txt
%doc doc/outdated/compress.txt
%doc doc/outdated/configuration.txt
%doc doc/outdated/expire.txt
%doc doc/outdated/fastcgi-state.txt
%doc doc/outdated/fastcgi.txt
%doc doc/outdated/features.txt
%doc doc/outdated/performance.txt
%doc doc/outdated/plugins.txt
%doc doc/outdated/proxy.txt
%doc doc/outdated/redirect.txt
%doc doc/outdated/rewrite.txt
%doc doc/outdated/scgi.txt
%doc doc/outdated/secdownload.txt
%doc doc/outdated/security.txt
%doc doc/outdated/setenv.txt
%doc doc/outdated/simple-vhost.txt
%doc doc/outdated/skeleton.txt
%doc doc/outdated/ssi.txt
%doc doc/outdated/ssl.txt
%doc doc/outdated/state.txt
%doc doc/outdated/status.txt
%doc doc/outdated/traffic-shaping.txt
%doc doc/outdated/userdir.txt
%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
%dir %attr(751,%{name},%{name}) %{pkg_home}/
%dir %attr(751,%{name},%{name}) %{pkg_home}/sockets/
%attr(751,%{name},%{name}) %{_var}/cache/%{name}/
%dir %{_var}/log/%{name}/

%files mod_rrdtool
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/rrdtool.conf
%doc doc/outdated/rrdtool.txt
%doc doc/scripts/rrdtool-graph.sh
%{_libdir}/%{name}/mod_rrdtool.so

%files mod_cml
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/cml.conf
%{_libdir}/%{name}/mod_cml.so
%doc doc/outdated/cml.txt

%files mod_magnet
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/magnet.conf
%{_libdir}/%{name}/mod_magnet.so
%doc doc/outdated/magnet.txt

%files mod_mysql_vhost
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/mysql_vhost.conf
%{_libdir}/%{name}/mod_mysql_vhost.so
%doc doc/outdated/mysqlvhost.txt

%files mod_trigger_b4_dl
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/trigger_b4_dl.conf
%{_libdir}/%{name}/mod_trigger_b4_dl.so
%doc doc/outdated/trigger_b4_dl.txt

%files mod_geoip
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/geoip.conf
%doc doc/geoip.txt
%{_libdir}/%{name}/mod_geoip.so

%files mod_webdav
%defattr(-,root,root,-)
%config(noreplace) %attr(640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/webdav.conf
%{_libdir}/%{name}/mod_webdav.so
%doc doc/outdated/webdav.txt

%changelog
* Tue Sep  1 2015 dimstar@opensuse.org
- Add perl(CGI) BuildRequires in order to be able to pass the test
  suite.
* Sun Aug 30 2015 jenkins@lighttpd.net
- update to 1.4.37
  + - next is 1.4.37
  + [mod_proxy] remove debug log line from error log (fixes #2659)
  + [mod_dirlisting] fix dir-listing.set-footer not showing
  + fix out-of-filedescriptors when uploading "large" files (fixes #2660, thx rmilecki)
  + increase upload temporary chunk file size from 1MB to 16MB
  + fix undefined integer shift
  + rewrite network (write) backends
  + [cmake] lowercase commands, whitespace cleanup, remove clutter in else(...), endif(...), endforeach(...)
  + [cmake] cleanup cache variables if features get deactivated
  + fix some unchecked return value warnings
  + maintain cq->bytes_in in chunk API; keep bytes_out/bytes_in synced
  + [cmake] don't put date into config.h (not used anyway), only unset local vars for disabled features instead of clearing cache
  + [cmake] fix FreeBSD linker bug
  + [tests] search for perl in PATH instead of /usr/bin; whitespace + test config cleanups
  + [kqueue] fix kevent call
  + [tests] fix warning about newline in filename
  + [autoconf] define HAVE_CRYPT when crypt() is present
  + [bsd xattr] fix compile break with BSD extended attributes in stat_cache
  + [mod_dirlisting] remove sys/syslimits.h; base.h already includes limits.h
  + small README for FreeBSD build setup
  + [build] put --as-needed into linker flags instead of cflags
  + [mod_cgi] rewrite mmap and generic (post body) send error handling
  + [mmap] fix mmap alignment
  + [plugins] when modules are linked statically still only load the modules given in the config
  + [scons] various improvements
  + [mmap] handle SIGBUS in network; those get triggered if the file gets smaller during reading
  + [scons] fix crypt() detection, other improvements
  + [scons] fix build
  + fix some warnings found by coverity ("leak" in setup phase, not catching too long unix socket paths in mod_proxy)
  + packdist.sh: use fakeroot for make dist to have root owned files in tar
* Mon Aug 10 2015 mrueckert@suse.de
- do not use the full url as we are reusing the debian tarball.
* Sun Jul 26 2015 jenkins@lighttpd.net
- update to 1.4.36
  + [configfile] fix reading uninitialized variable (found by Willian B.)
  + [dist] add dist-xz, remove dist-bzip2, allow ~rc appendix in packdist.sh
* Sat Jul 11 2015 jenkins@lighttpd.net
- update to 1.4.36~rc1
  + - next is 1.4.36
  + use keep-alive timeout while waiting for HTTP headers; use always the read timeout while waiting for the HTTP body
  + fix bad shift in conditional netmask ".../0" handling
  + add more mime types and a script to generate mime.conf (fxies #2579)
  + fix typo in NEWS entry for #2579
  + add support for (Free)BSD extended attributes
  + [build] use fortify flags with "extra-warnings"
  + [mod_dirlisting,mod_redirect,mod_rewrite] abort config parsing if pcre-compile fails or isn't available
  + [ssl] disable SSL3.0 by default
  + Fixed typo found by openSUSE user (boo# 907709)
  + add NEWS entry for previous commit
  + [network] fix compile break in calculation of sockaddr_un size if SUN_LEN is not defined (fixes #2609)
  + [connections] fix bug in connection state handling
  + print backtrace in assert logging with libunwind
  + fix buffer, chunk and http_chunk API
  + Remove chunkqueue_get_{append,prepend}* API
  + Remove buffer_prepare_copy() and buffer_prepare_append()
  + [tests] improve valgrind and strace TRACEME, disable condition logging in normal configs
  + Use buffer API to read and modify "used" member
  + rename buffer_append_long_hex to buffer_append_uint_hex
  + [buffer] constify some parameters
  + [bitset] unused -> remove
  + remove unused stuff from server.h
  + [crc32] fix method signature (const pointer)
  + [tests] fix undefined index warning in sendfile.php
  + [mod_auth] use crypt_r instead of crypt if available
  + fix error message for T_CONFIG_ARRAY config values if an entry value is not a string
  + fix segfaults in many plugins if they failed configuration
  + escape all strings for logging (fixes #2646 log file injection, reported by Jaanus Kääp)
  + add some until now missing files to dist tarball
  + minor spelling fixes
  + fix hex escape in accesslog (fixes #2559)
  + show extforward re-run warning only with debug.log-request-handling (fixes #2561)
  + parse If-None-Match for ETag validation (fixes #2578)
  + check pointer before usage in new etag compare
  + fix memory leak in mod_status when no counters are set (found by coverity)
  + #ifdef all parts belonging to the connection-state debugging
  + [mod_magnet] fix segfault when accessing not existing lighty.req_env[] entry (found by coverity)
  + fix segfault when temp file for upload couldn't be created (found by coverity)
  + check fcgi_env_add return value (found by coverity)
  + mime.conf: add some new mime types, remove .dat, .sha1, .md5, update .vcf
  + [mod_proxy] add unix domain socket support (fixes #2653)
* Sat Jun 20 2015 stbuehler@web.de
- define and use pkg_name, pkg_version, tarball_version
- use debian orig tarball
- fix download url
* Sat Feb 28 2015 tchvatal@suse.com
- Deb .orig.tar.bz2 -> regular tar, hopefully it shall work.
* Sat Feb 28 2015 tchvatal@suse.com
- Spec-cleanify and remove sle9 support fun
- Fix rpmlint warnings
- Use tarball fetchable from upstream
- Remove all obsolete conditions
* Sat Feb 28 2015 tchvatal@suse.com
- Remove the debian changelog also from the .spec file SOURCES
* Fri Feb 27 2015 tchvatal@suse.com
- Remove debian changelog as it collides with factory checkers
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Wed Jul 16 2014 mrueckert@suse.de
- added debian changelog file to the file list
* Tue Mar 18 2014 mrueckert@suse.de
- use gamin-devel only on 12.00 and newer but stick to fam-devel on
  older distros.
* Tue Mar 18 2014 mrueckert@suse.de
- update to version 1.4.35 (CVE-2014-2323 CVE-2014-2324 bnc#867350)
  * [network/ssl] fix build error if TLSEXT is disabled
  * [mod_fastcgi] fix use after free (only triggered if fastcgi
    debug is active)
  * [mod_rrdtool] fix invalid read (string not null terminated)
  * [mod_dirlisting] fix memory leak if pcre fails
  * [mod_fastcgi,mod_scgi] fix resource leaks on spawning backends
  * [mod_magnet] fix memory leak
  * add comments for switch fall throughs
  * remove logical dead code
  * [buffer] fix length check in buffer_is_equal_right_len
  * fix resource leaks in error cases on config parsing and other
    initializations
  * add force_assert() to enforce assertions as simple assert()s
    are disabled by -DNDEBUG (fixes #2546)
  * [mod_cml_lua] fix null pointer dereference
  * force assertion: setting FD_CLOEXEC must work (if available)
  * [network] check return value of lseek()
  * fix unchecked return values from
    stream_open/stat_cache_get_entry
  * [mod_webdav] fix logic error in handling file creation error
  * check length of unix domain socket filenames
  * fix SQL injection / host name validation (thx Jann Horn)
- additional changes in 1.4.34
  * [mod_auth] explicitly link ssl for SHA1 (fixes #2517)
  * [mod_extforward] fix compilation without IPv6, (not) using
    undefined var (fixes #2515, thx mm)
  * [ssl] fix SNI handling; only use key+cert from SNI specific
    config (fixes #2525, CVE-2013-4508)
  * [doc] update ssl.cipher-list recommendation
  * [stat-cache] FAM: fix use after free (CVE-2013-4560)
  * [stat-cache] fix FAM cleanup/fdevent handling
  * [core] check success of setuid,setgid,setgroups (CVE-2013-4559)
  * [ssl] fix regression from CVE-2013-4508 (client-cert sessions
    were broken)
  * maintain physical.basedir (the "acting" doc-root as prefix of
    physical.path) in more places
  * [core] decode URL before rewrite, enabling it to work in
    $HTTP["url"] conditionals (fixes #2526)
  * [auto* build] remove -no-undefined from linker flags, as we
    actually link modules with undefined symbols (fixes #2533)
  * [mod_mysql_vhost] fix memory leak on config init (#2530)
  * [mod_webdav] fix fd leak found with parfait (fixes #2530, thx
    kukackajiri)
- refreshed lighttpd-1.4.13_geoip.patch to apply cleanly
* Wed Jan  8 2014 adrian@suse.de
- use gamin-devel instead of unmaintained fam(-devel) package
* Mon Oct 21 2013 stbuehler@web.de
- remove patches
  - lighttpd-automake.patch: the m4_ifdef stuff should call AM_PROG_AR if available
  - lighttpd-serial-tests.patch: serial-tests only works with automake 1.12;
    upstream fixed configure.ac detecting automake version.
- update debian to 1.4.33-1 (official package)
  - back to .bz2 tar
- backport debian package (1.4.33-1~bpo70+0.1)
  - removing dh_systemd dependency and usage
* Fri Sep 27 2013 stbuehler@web.de
- update to 1.4.33:
  - mod_fastcgi: fix mix up of "mode" => "authorizer" in other fastcgi configs (fixes #2465, thx peex)
  - fix handling of If-Modified-Since if If-None-Match is present (don't return 412 for date parsing errors);
    follow current draft for HTTP/1.1, which tells us to ignore If-Modified-Since if we have matching etags.
  - [mod_fastcgi,log] support multi line logging (fixes #2252)
  - call ERR_clear_error only for ssl connections in CON_STATE_ERROR
  - reject non ASCII characters in HTTP header names
  - [mod_auth] use crypt() on encrypted password instead of extracting salt first (fixes #2483)
  - [mod_auth] add htpasswd -s (SHA1) support if openssl is used (needs openssl for SHA1). This doesn't use any salt, md5 with salt is probably better.
  - [mod_auth] fix base64_decode (#2484)
  - fix some bugs found with canalyze (fixes #2484, thx Zhenbo Xu)
  - fix undefined stuff found with clang
  - [cmake] Use TARGET_LINK_LIBRARIES instead of LINK_FLAGS for library dependencies, also add -Wl,--as-needed to extra warnings (fixes #2448)
  - [mod_auth] fix invalid read in digest qop=auth-int handling (fixes #2478)
  - [auto* build] simplify autogen.sh, handle automake 1.13 test running (fixes #2490)
  - [mod_userdir] add userdir.active option, "enabled" by default
  - [core] return 501 Not Implemented in static file mode for all methods except GET/POST/HEAD/OPTIONS
  - [core] recognize more http methods to forward to backends (fixes #2346)
  - [ssl] use DH only if openssl supports it (fixes #2479)
  - [network] use constants available at compile time for maximum number of chunks for writev instead of calling sysconf (fixes #2470)
  - [ssl] Fix $HTTP["scheme"] conditional, could be "http" for ssl connections if the ssl $SERVER["socket"] conditional was nested (fixes #2501)
  - [ssl] accept ssl renegotiations if they are not disabled (fixes #2491)
  - [ssl] add option ssl.empty-fragments, defaulting to disabled (fixes #2492)
  - [auth] put REMOTE_USER into cgi environment, making it accessible to lua via lighty.req_env (fixes #2495)
  - [auth] new method "extern" to use already present REMOTE_USER (from magnet, ssl, ...) (fixes #2436)
  - [core] remove requirement that default doc-root has to exist, there are reasonable scenarios not requiring static files at all
  - [core] check whether server.chroot exists
  - [mod_simple_vhost] fix cache; skip module if simple-vhost.server-root is empty (thx rm for reporting)
  - [mod_accesslog] add accesslog.syslog-level option (fixes #2480)
  - [core] allow files to be used as document-root (fixes #2475)
  - [core] set signal handlers before forking child processes in modules/plugins_call_set_defaults (fixes #2502)
* Tue Jun 25 2013 pgajdos@suse.com
- with gcc 4.8 parallel tests seems to be broken
  * lighttpd-serial-tests.patch
* Wed Nov 21 2012 mrueckert@suse.de
- update to 1.4.32: bnc#790258 CVE-2012-5533
  - Code cleanup with clang/sparse (fixes #2437, thx kibi)
  - Ignore EPIPE/ECONNRESET after SSL_shutdown
  - Handle ENAMETOOLONG, return 404 Not Found (fixes #2396, thx
    dererkazo)
  - configure.ac: remove old stuff, add some new to fix warnings in
    automake 1.12 (fixes #2419, thx blino)
  - add PATCH method (fixes #2424)
  - fix :port handling in $HTTP["host"] checks (fixes #2135. thx
    liming)
  - network_server_init: fix double free and memleak on error
    (fixes #2440, thx kyprizel)
  - detect "x-gzip"/"x-bzip2" as separate encodings, more strict
    encoding matching (fixes #2443)
  - tests: make sure mod_proxy doesn't leave running processes
    (fixes #2435, thx kibi)
  - mod_extforward: log address of untrusted proxy with
    debug.log-request-handling
  - fix DoS in Connection header value split (reported by Jesse
    Sipprell, CVE-2012-5533)
  - remove whitespace at end of header keys
- refreshed lighttpd-automake.patch
* Wed Jun 13 2012 mrueckert@suse.de
- dropped the perl line that mangled configure.ac
- moved automake patch into the geoip conditional
- move lua conditional out of the _repository block
* Mon Jun 11 2012 mrueckert@suse.de
- Fix the previous change:
  We only need that patch on 12.2
* Thu Jun  7 2012 pgajdos@suse.com
- fixed build (automake)
  * automake.patch
* Thu May 31 2012 mrueckert@suse.de
- update to 1.4.31
  - [ssl] fix segfault in counting renegotiations for openssl
    versions without TLSEXT/SNI (thx carpii for reporting)
  - Move fdevent subsystem includes to implementation files to
    reduce conflicts (fixes #2373)
  - [mod_compress] fix handling if etags are disabled but cache-dir
    is set - may lead to double response
  - disable mmap by default (fixes #2391)
  - buffer_caseless_compare: always convert letters to lowercase to
    get transitive results, fixing array lookups (fixes #2405)
  - Fix handling of empty header list entries in
    http_request_split_value, fixing invalid read in valgrind
    (fixes #2413)
  - Fix access log escaping of " and \\ (fixes #1551)
  - [mod_auth] Fix digest "md5-sess" implementation (Errata ID
    1649, RFC 2617) (fixes #2410)
  - [auth] Add "AUTH_TYPE" environment (for *cgi), remove fastcgi
    specific workaround, add fastcgi test case (fixes #889)
  - [mod_*cgi,mod_accesslog] Fix splitting :port with ipv6 (fixes
    [#2333], thx simoncpu)
  - Detect multiple -f options: show error message instead of
    assert (fixes #2416)
  - [mod_extforward] Support ipv6 addresses (fixes #1889)
  - [mod_redirect] Support url.redirect-code option (fixes #2247)
  - Fix --enable-mmap handling in configure.ac
* Tue Mar 20 2012 mrueckert@suse.de
- fix build on factory:
  do not use lua 5.2, use 5.1 instead
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Dec 21 2011 mrueckert@suse.de
- added the debian.tar.gz to the file list of the spec file to pass
  the check in factory
* Sun Dec 18 2011 mrueckert@suse.de
- update to 1.4.30
  - Always use our ‘own’ md5 implementation, fixes linking issues
    on MacOS (fixes #2331)
  - Limit amount of bytes we send in one go; fixes stalling in one
    connection and timeouts on slow systems.
  - [ssl] fix build errors when Elliptic-Curve Diffie-Hellman is
    disabled
  - Add static-file.disable-pathinfo option to prevent handling of
    urls like …/secret.php/image.jpg as static file
  - Don’t overwrite 401 (auth required) with 501 (unknown method)
    (fixes #2341)
  - Fix mod_status bug: always showed “0/0” in the “Read” column
    for uploads (fixes #2351)
  - [mod_auth] Fix signedness error in http_auth
    (fixes #2370, CVE-2011-4362)
  - [ssl] count renegotiations to prevent client renegotiations
  - [ssl] add option to honor server cipher order
    (fixes #2364, BEAST attack)
  - [core] accept dots in ipv6 addresses in host header
    (fixes #2359)
  - [ssl] fix ssl connection aborts if files are larger than the
    MAX_WRITE_LIMIT (256kb)
  - [libev/cgi] fix waitpid ECHILD errors in cgi with libev
    (fixes #2324)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Oct  2 2011 coolo@suse.com
- avoid endless loop in tests by using the right php path for 12.1
* Mon Jul 11 2011 mrueckert@suse.de
- update to 1.4.29
  - Fix mod_proxy waiting for response even if content-length is 0
    (fixes #2259)
  - Silence annoying "connection closed: poll() -> ERR" error.log
    message (fixes #2257)
  - mod_cgi: make read buffer as big as incoming data block
  - [build] Fix detection of libev (fixes #2300)
  - ssl: Support for Diffie-Hellman and Elliptic-Curve
    Diffie-Hellman key exchange (fixes #2301)
    add ssl.use-sslv3 (fixes #2246)
    load all algorithms (fixes #2239)
  - [ssl/md5] prefix our own md5 implementation with li_ so it
    doesn't conflict with the openssl one (fixes #2269)
  - [ssl/build] some minor fixes; fix compile without ssl, cleanup
    ssl config buffers
  - [proc,include_shell] log error if exec shell fails (fixes
    [#2280])
  - [*cgi] Use physical base dir (alias, userdir) as DOCUMENT_ROOT
    in cgi environments (fixes #2216)
  - [doc] Move docs to outdated/ subdir and refer to wiki instead
    (fixes #2248)
  - fdevent: add solaris eventports (fixes #2171)
* Sun Sep 19 2010 jengelh@medozas.de
- Do not specify -TERM signal for killproc. This causes killproc
  to not wait until the daemon actually terminated, which would
  result in a subsequent startproc call (as done by the "restart"
  action) to not do anything.
* Sun Aug 22 2010 stbuehler@web.de
- update 1.4.28
  - Rename fdevent_event_add to _set to reflect what the function
    does. Fix some handlers. (fixes #2249)
  - Fix buffer.h to include stdio.h as it is needer for SEGFAULT
    (fixes #2250)
* Mon Aug 16 2010 mrueckert@suse.de
- fix building on sles9
  - disable ustar
  - use find | xargs instead of -delete
* Mon Aug 16 2010 mrueckert@suse.de
- update 1.4.27
  - Fix handling return value of SSL_CTX_set_options
    (fixes #2157, thx mlcreech)
  - Fix mod_proxy HUP handling (send final chunk, fix usage
    counter)
  - mod_proxy: close connection on write error (fixes #2114)
  - Check uri instead of physical path for directory redirect
  - Fix detecting git repository (fixes #2173, thx ncopa)
  - [mod_compress] Fix segfault when etags are disabled
    (fixes #2169)
  - Reset uri.authority before TLS servername handling, reset all
    "keep-alive" data in connection_del (fixes #2125)
  - Print double quotes properly when dumping config file
    (fixes #1806)
  - Include IP addresses on error log on password failures
    (fixes #2191)
  - Fix stalls while reading from ssl sockets (fixes #2197)
  - Fix etag formatting on boxes with 32-bit longs
  - Fix two compiler warnings
  - mod_accesslog: fix %%p for ipv6 sockets
    (fixes #2228, thx jo.henke)
  - mod_fastcgi: Send 502 "Bad Gateway" if we couldn't open the
    file for X-Sendfile (fixes #2226)
  - mod_staticfile: add debug output if we ignore a file with
    static-file.exclude-extensions (fixes #2215)
  - mod_cgi: fix race condition leaving response not forwarded to
    client (fixes #2217)
  - mod_accesslog: Fix var declarations mixed in source
    (fixes #2233)
  - mod_status: Add version to status page (fixes #2219)
  - mod_accesslog: optimize accesslog_append_escaped
    (fixes #2236, thx crypt)
  - openssl: silence annoying error messages for errno==0
    (fixes #2213)
  - array.c: improve array_get_unused_element to check data type;
    fix mem leak if unused_element didn't find a matching entry
    (fixes #2145)
  - add check to stop loading plugins twice
  - cleanup fdevent code, removed linux-rtsig handler, replaced
    some fprintf calls
  - only require FDEVENT_IN bit to be set for listening connections
    (fixes #2227)
  - add libev fdevent handler: server.event-handler = "libev"
  - mod_proxy: return response as soon as it is available
    (fixes #2196)
  - don't overwrite global server.force-lowercase-filenames setting
    (fixes #2042)
  - bind to IPV6-only if ipv6 address was specified
    (http://redmine.lighttpd.net/projects/lighttpd/wiki/IPv6-Config)
- drop lighttpd-ssl-retval-fix.patch: included in the release
- drop config.tar.bz2, our config is now the upstream config!:)
* Thu Apr 22 2010 mrueckert@suse.de
- use the pid file for killing the lighttpd to avoid killing other
  services which are using the lighttpd binary. (bnc#559534)
* Thu Apr 15 2010 mt@suse.de
- added lighttpd-ssl-retval-fix.patch:
  Applied patch fixing start failure with enabled SSL because
  of not properly checked SSL_CTX_set_options() return value
  (http://redmine.lighttpd.net/issues/2157).
* Thu Feb 11 2010 mrueckert@suse.de
- update 1.4.26
  - Fix request parser to handle packets with splitted \r\n\r\n
    (fixes #2105)
  - Remove dependency on automake >= 1.11 with m4_ifdef check
  - mod_accesslog: support %%e (fixes #2113, thx presbrey)
  - Fix mod_cgi cgi.execute-x-only option in global block
  - mod_fastcgi: x-sendfile2 parse error debugging
  - Fix mod_proxy dead host detection if connect() fails
  - Fix fd leaks in mod_cgi (fds not closed on pipe/fork failures,
    found by Rodrigo, fixes #2158, #2159)
  - Fix segfault with broken rewrite/redirect patterns (fixes
    [#2140], found by crypt)
  - Append to previous buffer in con read, fix DoS/OOM
    vulnerability (fixes #2147, found by liming, CVE-2010-0295)
  - Fix HUP detection in close-state if event-backend doesn't
    support FDEVENT_HUP (like select or poll on FreeBSD)
- dropping fix-slow-request-dos-in-1.4.x.patch:
  included in release
* Mon Feb  1 2010 mrueckert@suse.de
- added fix-slow-request-dos-in-1.4.x.patch:
  fix a bug that makes lighttpd allocate too much memory
  for handling a request.  (bnc#573948) CVE-2010-0295
* Sun Nov 22 2009 stbuehler@web.de
- update 1.4.25
  - mod_magnet: fix pairs() for normal tables and strings (fixes
    [#1307])
  - mod_magnet: add traceback for printing lua errors
  - mod_rewrite: fix compile error if compiled without pcre
  - disable warning "CLOSE-read" (fixes #2091)
  - mod_rrdtool: fix creating file if it doesn't exist (#1788)
  - reset tlsext_server_name in connection_reset - fixes random
    hostnames in the $HTTP["host"] conditional
  - export some SSL_CLIENT_* vars for client cert validation
    (fixes #1288, thx presbrey)
  - mod_fastcgi: fix mod_fastcgi packet parsing
  - mod_fastcgi: Don't reconnect after connect() succeeded
    (fixes #2096)
  - Fix configure.ac to allow autoreconf, also enables make V=0
- dropped lighttpd-1.4.24_mod_magnet_regression.patch:
  included in update
- added lighttpd-configure_ac.patch:
  - remove fancy options which are not supported in older
    autoconf versions
- drop '-fi' option from autoreconf, so the libtool script
  isn't overwritten (as the overwritten one was broken).
  autoreconf is still needed for mod_geoip
- drop --with-webdav from ./configure (not an option)
- remove spawn-fcgi handling as it is removed from the source now
- remove ChangeLog from %%docs (has been removed upstream)
- man page was moved from section 1 to 8
* Mon Oct 26 2009 mrueckert@suse.de
- update 1.4.24
  - Add T_CONFIG_INT for bigger integers from the config
    (needed for #1966)
  - Use unsigned int (and T_CONFIG_INT) for max_request_size
  - Use unsigned int for secdownload.timeout (fixes #1966)
  - Keep url/host values from connection to display information
    while keep-alive in mod_status (fixes #1202)
  - Add server.breakagelog, a "special" stderr (fixes #1863)
  - Fix config evaluation for debug.log-timeouts option (#1529)
  - Add "cgi.execute-x-only" to mod_cgi, requires +x for cgi
    scripts (fixes #2013)
  - Fix FD_SETSIZE comparision warnings
  - Add "lua-5.1" to searched pkg-config names for lua
  - Fix unused function webdav_lockdiscovery in mod_webdav
  - cmake: Fix crypt lib check
  - cmake: Add -export-dynamic to link flags, fixes build on
    FreeBSD
  - Set FD_CLOEXEC for bound sockets before pipe-logger forks
    (fixes #2026)
  - Reset ignored signals to SIG_DFL before exec() in fastcgi/scgi
    (fixes #2029)
  - Show "no uri specified -> 400" error only when
    "debug.log-request-header-on-error" is enabled (fixes #2030)
  - Fix hanging connection in mod_scgi (fixes #2024)
  - Allow digits in hostnames in more places (fixes #1148)
  - Use connection_reset instead of handle_request_done for cleanup
    callbacks
  - Change mod_expire to append Cache-Control instead of
    overwriting it (fixes #1997)
  - Allow all comparisons for $SERVER["socket"] - only bind for
    "=="
  - Remove strptime failed message (fixes #2031)
  - Fix issues found with clang analyzer
  - Try to fix server.tag issue with localized svnversion
  - Fix handling network-write return values (#2024)
  - Use disable-time in fastcgi for all disables after errors,
    default is 1sec (fixes #2040)
  - Remove adaptive spawning code from fastcgi (was disabled for a
    long time)
  - Allow mod_mysql_vhost to use stored procedures (fixes #2011,
    thx Ben Brown)
  - Fix ipv6 in mod_proxy (fixes #2043)
  - Print errors from include_shell to stderr
  - Set tm.tm_isdst = 0 before mktime() (fixes #2047)
  - Use linux-epoll by default if available (fixes #2021, thx Olaf
    van der Spek)
  - Print an error if you use too many captures in a regex pattern
    (fixes #2059)
  - Combine Cache-Control header value in mod_expire to existing
    HTTP header if header already added by other modules
    (fixes #2068)
  - Remember keep-alive-idle in separate variable (fixes #1988)
  - Fix header inclusion order, always include "config.h" before
    any system header
  - mod_webdav: Patch to skip login information for domain part of
    Destination field (fixes #1793)
  - mod_webdav: Delete old properties before updating new for MOVE
    (fixes #1317)
  - Read hostname from absolute uris in the request line
    (fixes #1937)
  - mod_fastcgi: don't disable backend if disable-time is 0
    (fixes #1825)
  - mod_compress: match partial+full content-type (fixes #1552)
  - mod_fastcgi: fix is_local detection, respawn backends if
    bin-path is set (fixes #897)
  - Fix linger-on-close behaviour to avoid rare failure conditions
    (was r2636, fixes #657)
  - mod_fastcgi: restart local procs immediately after they
    terminated, fix local procs handling
  - Fix segfault on invalid config "duplicate else conditions"
    (fixes #2065)
  - mod_usertrack: Use T_CONFIG_INT for max-age, solves range
    problem (#1455)
  - mod_accesslog: configurable timestamp logging (fixes #1479)
  - always define _GNU_SOURCE
  - Add some iterators for mod_magnet (fixes #1307)
  - Fix close_timeout_ts trigger (should finally fix lingering
    close)
  - mod_rewrite: add url.rewrite-[repeat-]if-not-file to rewrite if
    file doesn't exist or is not a regular file (fixes #985, thx
    lucas aerbeydt)
  - Add TLS servername indication (SNI) support (fixes #386, thx
    Peter Colberg <peter@colberg.org>)
  - Add SSL Client Certificate verification (#1288)
  - mod_fastcgi: Fix host->active_procs counter, return 503 if
    connect wasn't successful after 5 tries (fixes #1825)
  - mod_accesslog: escape special characters (fixes #1551, thx icy)
  - fix mod_webdav crash from #1793 (fixes #2084, thx hiroya)
  - Don't print ssl error if client didn't support TLS SNI
  - Fix linger close timeout handling, drop timeout to 5 seconds
    (fixes #2086)
  - Fix broken return values from int to enum in mod_fastcgi
- added lighttpd-1.4.24_mod_magnet_regression.patch:
  * mod_magnet: fix pairs() for normal tables and strings
    (fixes #1307)
  * mod_magnet: add traceback for printing lua errors
* Wed Jun 24 2009 mrueckert@suse.de
- update to 1.4.23
  - Added some extra warning options in cmake and fix the resulting
    warnings (unused/static functions)
  - New lighttpd man page (moved it to section 8) (fixes #1875)
  - Create rrd file for empty rrdfile in mod_rrdtool (#1788)
  - Fix workaround for incorrect path info/scriptname if fastcgi
    prefix is "/" (fixes #729)
  - Finally removed spawn-fcgi
  - Allow xattr to overwrite mime type (fixes #1929)
  - Remove link from errormsg about fastcgi apps (fixes #1942)
  - Strip trailing dot from "Host:" header
  - Remove the optional port info from SERVER_NAME (thx Mr_Bond)
  - Fix mod_proxy RoundRobin (off by one problem if only one
    backend is up)
  - Rename configure.in to configure.ac, with small cleanups (fixes
    [#1932])
  - Add proper SUID bit detection (fixes #416)
  - Check for regular file in mod_cgi, so we don't try to start
    directories
  - Include mmap.h from chunk.h to fix some problems with #define
    mmap mmap64 (fixes #1923)
  - Add support for pipe logging for server.errorlog (fixes #296)
  - Add revision number to package version for svn/git checkouts
  - Use server.tag for SERVER_SOFTWARE if configured (fixes #357)
  - Fix trailing zero char in REQUEST_URI after "strip-request-uri"
    in mod_fastcgi
  - mod_magnet: Add env["request.remote-ip"] (fixes #1740)
  - mod_magnet: Add env["request.path-info"]
  - Change name/version separator back to "/" (affects every place
    where the version is printed)
  - Fix bug with FastCGI request id overflow under high load; just
    use always id 1 as we don't use multiplexing. (thx jgray)
  - Add some dirlisting enhancements (fixes #1458)
  - Add option to enable TCP_DEFER_ACCEPT (fixes #1447)
  - Limit amount of bytes read for one read-event (fixes #1070)
  - Add evasive.silent option (fixes #1438)
  - Make mod_extforward headers configurable (fixes #1545)
  - Add '%%_' pattern for complete hostname in mod_evhost (fixes
    [#1737])
  - Add IPv6 support to mod_proxy (fixes #1537)
  - mod_ssi printenv: print cgi env, add environment vars to cgi
    env (fixes #1713)
  - Fix error message if no auth backend was set
  - Fix SERVER_NAME port stripping (fixes #1968)
  - Fix x-sendfile 2gb limiting (fixes #1970)
  - Fix mod_cgi environment keys mangling (fixes #1969)
  - Fix workaround for incorrect path info/scriptname if scgi
    prefix is "/" (fixes #729)
  - Fix max-age value in mod_expire for 'modification' (fixes
    [#1978])
  - Fix evasive.silent option (#1438)
  - Fix mod-fastcgi counters
  - Modify fastcgi error message
  - Backup errno for later usage (reported by Guido Reina via
    mailinglist)
  - Improve FastCGI performance (fixes #1999)
  - Workaround broken operating systems: check for trailing '/' in
    filenames (fixes #1989)
  - Allow using pcre with cross-compiling (pcre-config got fixed;
    fixes #1986)
  - Add "lighty.req_env" table to mod_magnet for setting/getting
    environment values for cgi (fixes #1967, thx presbrey)
  - Fix segfault in mod_expire after failed config parsing (fixes
    [#1992])
  - Add ssi.content-type option (default text/html, fixes #615)
  - Add support for "real" entropy from /dev/[u]random (fixes
    [#1977])
  - Adding support for additional chars in LDAP usernames (fixes
    [#1941])
  - Ignore multiple "If-None-Match" headers (only use first one,
    fixes #753)
  - Fix 100%% cpu usage if time() < 0 (thx to gaspa and cate, fixes
    [#1964])
  - Allow max-keep-alive-requests to depend on conditional (fixes
    [#1881])
  - Make dependency on svnversion/git optional (for devel
    versionstamp, fixes #2009)
* Mon Mar  9 2009 mrueckert@suse.de
- update to 1.4.22
  - Fix wrong lua type for CACHE_MISS/CACHE_HIT in mod_cml (fixes
    [#533])
  - Fix default vhost in mod_simple_vhost (fixes #1905)
  - Handle EINTR in mod_rrdtool (fixes #604)
  - Fix rrd error after graceful restart (fixes #419)
  - Fix EAGAIN handling for freebsd sendfile (fixes #1913, thx
    AnMaster for spotting the problem)
  - Fix segfault in mod_scgi (fixes #1911)
  - Treat EPIPE as connection-closed error in
    network_freebsd_sendfile.c (another fix from #1913)
  - Fix useless redirection of stderr in mod_rrdtool, as it gets
    redirected to /dev/null later. (fixes #1922)
  - Fix some problems with more strict compilers (#1923)
  - Fix segfault if siginfo_t* is NULL in sigaction handler (fixes
    [#1926])
- dropped lighttpd-1.4.x_fix_mod_simple_vhost_mod_cml.patch:
  included in update
* Thu Feb 26 2009 mrueckert@suse.de
- rely on the external spawn-fcgi package
* Wed Feb 18 2009 mrueckert@suse.de
- update to 1.4.21
  * Fix base64 decoding in mod_auth (#1757, thx guido)
  * Fix mod_cgi segfault when bound to unix domain socket (#653)
  * Do not rely on ioctl FIONREAD (#673)
  * Now really fix mod auth ldap (#1066)
  * Fix leaving zombie process with include_shell (#1777)
  * Removed debian/, openwrt/ and cygwin/; they weren’t kept
    up-to-date, and we decided to remove dist. specific stuff
  * Try to convert string options to shorts for numeric options in
    config file; allows to use env-vars for numeric options.
    (#1159, thx andrewb)
  * Do not cache default vhost in mod_simple_vhost (#709)
  * Trust pcre-config, do not check for pcre manually (#1769)
  * Fix fastcgi authorization in subdirectories with
    check-local=disabled; don’t split pathinfo for authorizer.
    (#963)
  * Add possibility to disable methods in mod_compress (#1773)
  * Fix duplicate connection keep-alive/transfer-encoding headers
    (#960)
  * Fixed fix for round-robin in mod_proxy (forgot to increment the
    index) (#1715)
  * Fix fastcgi-authorizer handling; Status: 200 is now accepted as
    the doc requests
  * Compare address family in inet_ntop_cache
  * Revert CVE-2008-4359 (#1720) fix “encoding+simplifying urls for
    rewrite/redirect”: too many regressions.
  * Use FD_CLOEXEC if possible (fixes #1821)
  * Optimized buffer usage in mod_proxy (fixes #1850)
  * Fix uninitialized value in time struct after strptime
  * Do not pass Proxy-Connection: header from client to backend
    http server in mod_proxy (#1877)
  * Fix wrong malloc sizes in mod_accesslog (probably nothing bad
    happened…) (fixes #1855, thx ycheng)
  * Some small buffer.c fixes (closes #1837)
  * Remove floating point math from server.c (fixes #1402)
  * Disable SSLv2 by default
  * Use/enforce sane max-connection values (fixes #1803)
  * Allow mod_compress to return 304 (Not Modified); compress
    ignores the static-file.etags option.(fixes #1884)
  * Add option to ignore the “Expect: 100-continue” header instead
    of returning 417 Expectation failed (closes #1017)
  * Use modified etags in mod_compress (fixes #1800)
  * Fix max-connection limit handling/100%% cpu usage (fixes #1436)
  * Fix error handling in freebsd-sendfile (fixes #1813)
  * Silenced the annoying “request timed out” warning, enable with
    the “debug.log-timeouts” option (fixes #1529)
  * Allow tabs in header values (fixes #1822)
  * Added Language conditional (fixes #1119 patch by petar
  * Fix wrong format strings (#1900, thx stepancheg)
- added lighttpd-1.4.x_fix_mod_simple_vhost_mod_cml.patch:
  fix mod_simple_vhost and a small typo in mod_cml
* Mon Nov 24 2008 mrueckert@suse.de
- as we build inside the obs now replace the opensuse_bs
  conditional with a conditional based on _repository.
* Thu Oct  2 2008 mrueckert@suse.de
- update to 1.4.20 (bnc#429764, bnc#374761)
  * Fix #285 again: read error after SSL_shutdown (thx
    marton.illes@balabit.com) and clear the error queue before some
    other calls (CVE-2008-1531)
  * Fix mod_magnet: enable "request.method" and "request.protocol"
    in lighty.env (#1308)
  * Fix segfault for appending matched parts if there was no regex
    matching (just give empty strings) (#1601)
  * Use data_response_init in mod_fastcgi x-sendfile handling for
    response.headers, fix a small "memleak" (#1628)
  * Don't send empty Server headers (#1620)
  * Fix conditional interpretation of core options
  * Enable escaping of %% and $ in redirect/rewrite; only two cases
    changed their behaviour: "%%%%" => "%%", "$$" => "$"
  * Fix accesslog port (should be port from the connection, not the
    "server.port") (#1618)
  * Fix mod_fastcgi prefix matching: match the prefix always
    against url, not the absolute filepath (regardless of check-local)
  * Overwrite Content-Type header in mod_dirlisting instead of
    inserting (#1614), patch by Henrik Holst
  * Handle EINTR in mod_cgi during write() (#1640)
  * Allow all http status codes by default; disable body only for
    204,205 and 304; generate error pages for 4xx and 5xx (#1639)
  * Fix mod_magnet to set con->mode = p->id if it generates
    content, so returning 4xx/5xx doesn't append an error page
  * Do not rely on PATH_MAX (POSIX does not require it) (#580)
  * Disable logging to access.log if filename is an empty string
  * Implement a clean way to open /dev/null and use it to close
    stdin/out/err in the needed places (#624)
  * merge spawn-fcgi changes from trunk (from @2191)
  * let spawn-fcgi propagate exit code from spawned fcgi application
  * close connection after redirect in trigger_b4_dl (thx icy)
  * close connection in mod_magnet if returned status code
  * fix bug with IPv6 in mod_evasive (#1579)
  * fix scgi HTTP/1.* status parsing (#1638), found by
    met@uberstats.com
  * fixed typo in mod_accesslog (#1699)
  * replaced buffer_{append,copy}_string with the _len variant
    where possible (#1732) (thx crypt)
  * case insensitive match for secdownload md5 token (#1710)
  * Handle only HEAD, GET and POST in mod_dirlisting (same as in
    staticfile) (#1687)
  * fixed mod_secdownload problem with unsigned time_t (#1688)
  * Use filedescriptor 0 for mod_scgi spawn socket, redirect STDERR
    to /dev/null (#1716)
  * fixed round-robin balancing in mod_proxy (#1715)
  * fixed EINTR handling for waitpid in mod_fastcgi
  * mod_{fast,s}cgi: overwrite environment variables (#1722)
  * inserted many con->mode checks; they should prevent two modules
    to handle the same request if they shouldn't (#631)
  * fixed url encoding to encode more characters (#266)
  * allow digits in [s]cgi env vars (#1712)
  * fixed dropping last character of evhost pattern (#161)
  * print helpful error message on conditionals in global
    block (#1550)
  * decode url before matching in mod_rewrite (#1720)
  * fixed conditional patching of ldap filter (#1564)
  * Match headers case insensitive in response (removing of
    X-{Sendfile,LIGHTTPD-*}, catching Date/Server)
  * fixed bug with case-insensitive filenames in mod_userdir
    (#1589), spotted by "anders1"
  * fixed format string bugs in mod_accesslog for SYSLOG
  * replaced fprintf with log_error_write in fastcgi debug
  * fixed mem leak in ssi expression parser (#1753), thx Take5k
  * hide some ssl errors per default, enable them with
    debug.log-ssl-noise (#397)
  * fix segfault for stat_cache(fam) calls with relative path
    (without '/', can be triggered by x-sendfile) (#1750)
  * fix splitting of auth-ldap filter
  * workaround ldap connection leak if a ldap connection failed
    (restarting ldap)
  * fix auth.backend.ldap.bind-dn/pw problems (only read from
    global context for temporary ldap reconnects, thx ruskie)
  * fix memleak in request header parsing (#1774, thx qhy)
  * fix mod_rewrite memleak/endless loop detection
    (#1775, thx phy - again!)
  * use decoded url for matching in mod_redirect (#1720)
- removed lighttpd-1.4.x_ssl_dos.patch: included in version update
- removed lighttpd-1.4.16_testsuite.patch:
  the path to the php-cgi binariy can now be configured with export
  of the variable PHP. adapt lightytest.sh accordingly.
- added a logrotate script provided by Carsten Hoeger (bnc#430565)
* Fri May 16 2008 mrueckert@suse.de
- added lighttpd-1.4.x_ssl_dos.patch: (bnc#374761)
  properly clear ssl errors before proceeding to the next connection
  (CVE-2008-1531)
* Tue Mar 11 2008 mrueckert@suse.de
- update to 1.4.19: (bnc#366526, bnc#364517, bnc#368670)
  * added support for If-Range: <date> (#1346)
  * added support for matching $HTTP["scheme"] in configs
  * fixed initgroups() called after chroot (#1384)
  * fixed case-sensitive check for Auth-Method (#1456)
  * execute fcgi app without /bin/sh if used as argument to
    spawn-fcgi (#1428)
  * fixed a bug that made /-prefixed extensions being handled also
    when matching the end of the uri in fcgi,scgi and proxy modules
    (#1489)
  * print error if X-LIGHTTPD-send-file cannot be done; reset
    header Content-Length for send-file. Patches by Stefan Buehler
  * prevent crash in certain php-fcgi configurations (#841)
  * add IdleServers and Scoreboard directives in ?auto mode for
    mod_status (#1507)
  * open log immediately after daemonizing, fixes SIGPIPEs on
    startup  (#165)
  * HTTPS env var should be "on" when using mod_extforward and the
    X-Forwarded-Proto header is set. (#1499)
  * generate ETag and Last-Modified headers for mod_ssi based on
    newest modified include (#1491)
  * support letterhomes in mod_userdir (#1473)
  * support chained proxies in mod_extforward (#1528)
  * fixed bogus "cgi died ?" if we kill the CGI process on shutdown
  * fixed ECONNRESET handling in network-openssl
  * fixed handling of EAGAIN in network-linux-sendfile (#657)
  * reset conditional cache (#1164)
  * create directories in mod_compress (was broken with
    alias/userdir) (#1027)
  * fixed out of range access in fd array (#1562, #372)
    (CVE-2008-0983)
  * mod_compress should check if the request is already handled,
    e.g. by fastcgi (#1565)
  * remove broken workaround for buggy Opera version with
    ssl/chunked encoding (#285)
  * generate etag/last-modified header for on-the-fly-compressed
    files (#1171)
  * req-method OPTIONS: do not insert default response if request
    was denied, do not deny OPTIONS by default (#1324)
  * fixed memory leak on windows (#1347)
  * fixed building outside of the src dir (#1349)
  * fixed including of stdint.h/inttypes.h in etag.c (#1413)
  * do not add Accept-Ranges header if range-request is disabled
    (#1449)
  * log the ip of failed auth tries in error.log (enhancement
    [#1544])
  * fixed RoundRobin in mod_proxy (#516)
  * check for symlinks after successful pathinfo matching (#1574)
  * fixed mod-proxy.t to run with a builddir outside of the src dir
  * do not suppress content on "307 Temporary Redirect" (#1412)
  * fixed Content-Length header if response body gets removed in
    connections.c (#1412, part 2)
  * do not generate a "Content-Length: 0" header for HEAD requests,
    added test too
  * remove compress cache file if compression or write failed
    (#1150)
  * fixed body handling of status 300 requests
  * spawn-fcgi: only try to connect to unix socket (not tcp) before
    spawning (#1575)
  * fix sending source of cgi script instead of 500 error if fork
    fails (CVE-2008-1111)
  * fix min-procs handling in mod_scgi.c, just set to max-procs
    (patch from #623)
  * fix sending "408 - Timeout" instead of "410 - Gone" for
    timedout urls in mod_secdownload (#1440)
  * workaround #1587: require userdir.path to be set to enable
    mod_userdir (empty string allowed) (CVE-2008-1270)
  * make configure checks for --with-pcre, --with-zlib and
  - -with-bzip2 failing if the headers aren't found
  * fixed handling of waitpid() == EINTR mod_ssi on solaris
* Sun Oct  7 2007 mrueckert@suse.de
- use distro lua on 10.3 or newer
* Sun Sep  9 2007 mrueckert@suse.de
- update to 1.4.18 (#307749)
  * fixed compile error on IRIX 6.5.x on prctl() (#1333)
  * fixed forwarding a SIGINT and SIGHUP when using max-workers
    (#902)
  * fixed FastCGI header overrun in mod_fastcgi
    (reported by mattias@secweb.se)
  * fixed hanging redirects with keep-alive due to missing
    "Content-Length: 0" headers
  * fixed crashing when using undefined environment variables in
    the config
  * fixed compilation of mod_mysql_vhost on irix (#1341)
* Wed Aug 29 2007 mrueckert@suse.de
- update to 1.4.17
  * added dir-listing.set-footer in mod_dirlisting (#1277)
  * added sending UID and PID for SIGTERM and SIGINT to the logs
  * fixed hardcoded font-sizes in mod_dirlisting (#1267)
  * fixed different ETag length on 32/64 platforms (#1279)
  * fixed compression of files < 128 bytes by disabling compression
  * (#1241)
  * fixed mysql server reconnects (#518)
  * fixed disabled keep-alive for dynamic content with HTTP/1.0
  * (#1166)
  * fixed crash on mixed EOL sequences in mod_cgi
  * fixed key compare (#1287)
  * fixed invalid char in header values (#1286)
  * fixed invalid "304 Not Modified" on broken timestamps
  * fixed endless loop on shrinked files with sendfile() on BSD
    (#1289)
  * fixed counter overrun in ?auto in mod_status (#909)
  * fixed too aggresive caching of nested conditionals (#41)
  * fixed possible overflow in unix-socket path checks on BSD
    (#713)
  * fixed extra Content-Length header on 1xx, 204 and 304 (#1002)
  * fixed handling of duplicate If-Modified-Since to return 304
  * fixed extracting status code from NPH scripts (#1125)
  * fixed prctl() usage (#1310)
  * removed config-check if passwd files exist (#1188)
  * fixed crash when etags are disabled but the client sends one
    (#1322)
  * fixed crash when freeing the config in mod_alias
  * fixed server.error-handler-404 breakage from 1.4.16 (#1270)
  * fixed entering 404-handler from dynamic content (#948)
  * added more debug infos for FAM based stat-cache
  * use more LSB like paths in the sample config (#1242)
* Wed Aug 22 2007 mrueckert@suse.de
- split the firewall files for http and https similar to apache
  (#247748)
* Mon Aug 20 2007 mrueckert@suse.de
- updated lighttpd-1.4.10_testsuite.patch
  new name lighttpd-1.4.16_testsuite.patch:
  - omit upstreamed snippet
* Wed Jul 25 2007 mrueckert@suse.de
- update to 1.4.16
  * added static-file.etags, etag.use-inode, etag.use-mtime,
    etag.use-size to customize the generation of ETags for static
    files. (#1209) (patch by <Yusufg@gmail.com>)
  * fixed typecast of NULL on execl() (#1235)
    (patch by F. Denis)
  * fixed circumventing url.access-deny by trailing slash (#1230)
  * fixed crash on duplicate headers with trailing WS (#1232)
  * fixed accepting more connections then requested (#1216)
  * fixed mem-leak in mod_auth (reported by Stefan Esser)
  * fixed crash with md5-sess and cnonce not set in mod_auth
    (reported by Stefan Esser)
  * fixed missing check for base64 encoded string in mod_auth and
    Basic auth (reported by Stefan Esser)
  * fixed possible crash in Auth-Digest header parser on trailing
    WS in mod_auth (reported by Stefan Esser)
  * fixed check on stale errno values, which broke handling of
    broken fastcgi applications. (#1245)
  * fixed crash on 32bit archs when debug-msgs are printed in
    mod_scgi, mod_fastcgi and mod_webdav (#1263)
- removed lighttpd-1.4.x_mod_status_orig_uri.patch:
  included upstream
* Fri May 25 2007 mrueckert@suse.de
- added lighttpd-1.4.x_mod_status_orig_uri.patch:
  show the original request uri in the mod_status output
* Mon May 14 2007 mrueckert@suse.de
- synced spec with the -snapshot rpms
* Thu Apr 19 2007 mrueckert@suse.de
- added /var/lib/lighttpd/sockets/
* Mon Apr 16 2007 mrueckert@suse.de
- update to 1.4.15:
  * fixed broken Set-Cookie headers
- additional changes from 1.4.14: (includes fixes for bnc:#246945)
  * fix crash if gethostbyaddr() failed on redirect [1718]
  * properly handle 206 responses generated by *cgi scripts.
    (#755) [1716]
  * added HTTPS=on to the environment of cgi scripts (#861) [1684]
  * fix handling of 303 (#1045) [1678]
  * made the configure check for lua more portable [1677]
  * added mod_extforward module [1665]
  * references to the fam stat cache engine should be conditional
    (#1039) [1664]
  * fix http 500 errors (colin.stephen/at/o2.com) #1041 [1663]
  * prevent wrong pidfile unlinking on graceful restart
    (Chris Webb) [1656]
  * ignore empty packets from STDERR stream. #998
  * fix a crash for files with an mtime of 0 reported by cubiq on
    irc [1519] CVE-2007-1870
  * allow empty passwords with ldap (Jörg Sonnenberger) [1516]
  * mod_scgi.c segfault fix #964 [1501]
  * Added round-robin support to mod_fastcgi [1500]
  * Handle DragonFlyBSD the same way as Freebsd
    (Jörg Sonnenberger) [1492,1676]
  * added now and weeks support to mod_expire. #943
  * fix cpu hog in certain requests [1473] CVE-2007-1869
  * fix for handling hostnames with trailing dot [1406]
  * fixed header-injection via server.tag (#1106)
  * disabled caching of files without a content-type to solve the
    aggressive caching of FF
  * remove trailing white-spaces from HTTP-requests before parsing
    (#1098)
  * fixed accesslog.use-syslog in a conditional and the caching of
    the accesslog for files (fixes #1064)
  * fixed various crashes at startup on broken accesslog.format
    strings (#1000)
  * fixed handling of %%%% in accesslog.format
  * fixed conditional dir-listing.exclude (#930)
  * reduced default PATH_MAX to 255 (#826)
  * ECONNABORTED is not known on cygwin (#863)
  * fixed crash on url.redirect and url.rewrite if %%0 is used in
    a global context (#800)
  * fixed possible crash in debug-message in mod_extforward
  * fixed compilation of mod_extforward on glibc < 2.3.4
  * fixed include of empty in the configfiles (#1076)
  * send SIGUSR1 to fastcgi children before SIGTERM. libfcgi
    wants SIGUSR1. (#737)
  * fixed missing AUTH_TYPE entry in the fastcgi environment.
    (#889)
  * fixed compilation in network_writev.c on MacOS X 10.3.9 (#903)
  * added kill-signal as another setting for fastcgi backends. See
    the wiki for more.
- fixed the default config: (#254820)
  it broke when module configs used variables
- added zlib-devel and libbz2-devel to the buildrequires for 10.3+
- added proper conditionals for older distros
- added optional mod_geoip module. (only build on the buildservice)
- added mod_magnet config file
* Mon Mar 26 2007 rguenther@suse.de
- Add gdbm-devel BuildRequires
* Sat Dec  2 2006 mrueckert@suse.de
- fixed building on sles9
* Thu Oct 19 2006 mrueckert@suse.de
- Factory has 5.1.1. so allow building against plain lua-devel
* Mon Oct  9 2006 mrueckert@suse.de
- update to 1.4.13:
- removed lighttpd-1.4.9.patch: fixed it upstream finally.
  * added initgroups in spawn-fcgi (#871)
  * added apr1 support htpasswd in mod-auth (#870)
  * added lighty.stat() to mod_magnet
  * fixed segfault in splitted CRLF CRLF sequences
    (introduced in 1.4.12) (#876)
  * fixed compilation of LOCK support in mod-webdav
  * fixed fragments in request-URLs (#869)
  * fixed pkg-config check for lua5.1 on debian
  * fixed Content-Length = 0 on HEAD requests without
    a known Content-Length (#119)
  * fixed mkdir() forcing 0700 (#884)
  * fixed writev() on FreeBSD 4.x and older (#875)
  * removed warning about a 404-error-handler
    returned 404
  * backported and fixed the buildsystem changes for
    webdav locks
  * fixed plugin loading so we can finally load lua
    extensions in mod_magnet scripts
  * fixed large uploads if xattr is enabled
- buildrequire lua51
* Mon Sep 25 2006 mrueckert@suse.de
- lighttpd.sysconfig/lighttpd.init:
  added LIGHTTPD_UMASK with a default value of "077" to make sure
  we have a sane umask. mod_webdav now honors the umask when
  creating new files.
* Sat Sep 23 2006 mrueckert@suse.de
- update to 1.4.12:
  o added experimental LOCK support for webdav
  o added Content-Range support for PUT in webdav
  o added support for += on empty arrays in config-files
  o added ssl.cipher-list and ssl.use-sslv2
  o added $HTTP["querystring"] conditional
  o added mod_magnet as long-term replacement for mod_cml
  o added work-around for a Opera Bug with SSL + Chunked-Encoding
  o changed --print-config to print to stdout instead of stderr
  o changed no longer use 0600 for new files with webdav. umask is
    honored. Make sure you have set a proper umask.
  o fixed upload hangs with SSL
  o fixed connection drops with SSL (aka bad retry)
  o fixed path traversal with \ on cygwin
  o fixed mem-leak in mod_flv_streaming
  o fixed required trailing newline in configfiles (#142)
  o fixed quoting the autoconf files (#466)
  o fixed empty Host: + $HTTP["host"] handling (#458)
  o fixed handling of If-Modified-Since if ETag is not set
  o fixed default-shell if SHELL is not set (#441)
  o fixed appending and assigning of env.* vars
  o fixed empty FCGI_STDERR packets
  o fixed conditional server.allow-http-11
  o fixed handling of follow-symlink + lstat()
  o fixed SIGHUP handling if max-workers is used
  o fixed "Software caused connection abort" messages on FreeBSD
- additional changes from 1.4.11:
  o added ability to specify which ip address spawn-fci listens on
    (agkr@pobox.com)
  o added mod_flv_streaming to streaming Flash Movies efficiently
  o fixed handling of error codes returned by mod_dav_svn behing a
    mod_proxy
  o fixed error-messages in mod_auth and mod_fastcgi
  o fixed re-enabling overloaded local fastcgi backends
  o fixed handling of deleted files in linux-sendfile
  o fixed compilation on BSD and MacOSX
  o fixed $SERVER["socket"] on a already bound socket
  o fixed local source retrieval on windows
    (secunia)
  o fixed hanging cgi if remote side is dieing while reading
    from the pipe (sandy@meebo.com)
* Thu Jul 20 2006 olh@suse.de
- remove unused neon from buildrequires
* Tue May 30 2006 mrueckert@suse.de
- updated to 1.4.10
  * added ability to specify which ip address spawn-fci listens on
  (agkr@pobox.com)
  * added mod_flv_streaming to streaming Flash Movies efficiently
  * fixed handling of error codes returned by mod_dav_svn behing a
  mod_proxy
  * fixed error-messages in mod_auth and mod_fastcgi
  * fixed re-enabling overloaded local fastcgi backends
  * fixed handling of deleted files in linux-sendfile
  * fixed compilation on BSD and MacOSX
  * fixed $SERVER["socket"] on a already bound socket
  * fixed local source retrieval on windows
  (secunia)
  * fixed hanging cgi if remote side is dieing while reading
  from the pipe (sandy@meebo.com)
- removed lighttpd-1.4.10_importantfixes.patch:
  all changes are upstream
- updated lighttpd-1.4.10_testsuite.patch:
  o removed max-request size
  o fixed count of the fastcgi tests.
* Mon Mar  6 2006 mrueckert@suse.de
- added lightytest.sh
  wrapper script around the test suite. so we properly cleanup the
  php-fastcgi process.
* Mon Mar  6 2006 mrueckert@suse.de
- added new splitted config (config.tar.bz2)
- added lighttpd-1.4.10_importantfixes.patch:
  + typo in mod_cml documentation (doc/cml.txt)
  + added paragraph about using var. and env.
  (doc/configuration.txt)
  + explain fastcgi.map-extensions (doc/fastcgi.txt)
  + include FAM_CFLAGS/SQLITE3_CFLAGS when needed (src/Makefile.am)
  + dont crash if using %%0 reference in a !~ conditional (tln #557)
  (src/configfile-glue.c)
  + handle additional request types/methods for webdav
  this allows proxying mod_dav_svn through lighttpd.
  (src/connections.c, src/keyvalue.c, src/keyvalue.h)
  + handle aliases correctly with force_lowercase_filenames
  (src/mod_alias.c)
  + improved error message for errors in the authentication config
  (src/mod_auth.c)
  + cgi module no longer resets physical path (mod_cgi.c)
  + close unused pipe-fds as soon as possible to generate a
  SIGPIPE if the remote end dies. (src/mod_cgi.c)
  + only send REQUEST_URI and QUERY_STRING if they are set
  (src/mod_cgi.c)
  + added host.load as status-variable (src/mod_fastcgi.c)
  + better handling for shrinking files
  (src/network_linux_sendfile.c)
  + don't init a SERVER["socket"] if it is initialized already
  (src/network.c)
  + fixed end of life memleaks (tln #524) (src/server.c)
  + removed umask(0);, let the old umask stay in place (tln #547)
  + test suite fixes (tests/mod-fastcgi.t, tests/request.t)
  + allow leading zeros in HTTP/01.01 (tln #542)
  (tests/core.t, src/request.c)
  + fixed handling of subdirs in ssi (tln #462) (src/mod_ssi.c)
- start lighttpd with a minimal environment
- added update for the server.tag in the config file
* Mon Feb 20 2006 mrueckert@suse.de
- split off mod_rrdtool
* Wed Feb  8 2006 mrueckert@suse.de
- update to version 1.4.10
  * added docs for mod_dirlisting
  * added fastcgi.map-extensions to mod_fastcgi
  * fixed load balancing for mod_fastcgi
  * fixed extra newline for syslog() in mod_accesslog
  * fixed user-track cookie for IE in mod_usertrack
  * fixed crash in digest handling in mod_auth
  * fixed handling of 301 response-bodies from a mod_proxy backend
  * fixed loading of base modules if server.modules is not set
  * fixed broken cgi if mod_scgi is loaded
- enabled test suite
- applied lighttpd-1.4.10_testsuite.patch
  - limits the max request size to 2GB. otherwise it would be 2^63-1
  on 64bit arches and one tests would fail.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 mrueckert@suse.de
- splitted up all modules that pull in extra dependencies
  lighttpd-mod_cml - lua, libmemcache
  lighttpd-mod_mysql_vhost - mysql-shared
  lighttpd-mod_trigger_b4_dl - libmemcache,gdbm
  lighttpd-mod_webdav - libxml2, sqlite3
* Mon Jan 23 2006 mrueckert@suse.de
- fix typo in the file section
* Sun Jan 15 2006 mrueckert@suse.de
- update to version 1.4.9
  * added server.core-files option (sandy)
  * added docs for mod_status
  * added mod_evasive to limit the number of connections by IP ()
  * added the power-magnet to mod_cml
  * added internal statistics to mod_fastcgi
  * added server.statistics-url to get internal statistics
    from mod_status
  * added support for conditional range-requests through If-Range
  * added static building via scons
  * fixed 100%% cpu loops in mod_cgi ("sandy" )
  * fixed handling for secure-download.timeout
    (jamis@37signals.com)
  * fixed IE bug in content-charset in the output of
    mod_dirlisting (sniper@php.net)
  * fixed typos and language in the docs
    (ryan-2005@ryandesign.com)
  * fixed assertion in mod_cgi on HEAD request is Content-Length ()
  * fixed handling if equal but duplicate If-Modified-Since request
    headers
  * fixed endless loops in mod_fastcgi if backend is dead
  * fixed Depth: 1 handling in PROPFIND requests on empty dirs
  * fixed encoding of UTF8 encoded dirlistings (Jani Taskinen )
  * fixed initial bind to a unix-domain socket through server.bind
  * fixed handling of lowercase filesystems
  * fixed duplicate request headers cause by mod_setenv
- added lighttpd-1.4.9_mod_fastcgi_crash.patch
  temporary fix a crash in the log message
* Wed Nov 23 2005 mrueckert@suse.de
- update to version 1.4.8
  * added auto-reconnect to ldap-server in mod_auth
  * changed auth.ldap-cafile to be optional
  * added strip_request_uri in mod_fastcgi
  * added more X-* headers to mod_proxy
  * added 'debug' to simple-vhost to suppress the messages by default
  * added support to let the server listen on UNIX-socket
  * changed default stat-cache-engine to 'simple'
  * removed debian/ dir from source package on request by packager
  * fixed max-age timestamps in mod_expire
  * fixed encoding the filenames in PROPFIND in mod_webdav
  * fixed range request handling in network_writev
  * fixed retry on connect error in mod_fastcgi
  * fixed possible crash in mod_webdav if sqlite3 support
    is available but not use
  * fixed fdvent-handler init if server.max-worker was used
  * fixed missing cleanup in mysql_vhost
  * fixed assert() in "connections.c:962:
    connection_handle_read_state: Assertion 'c->mem->used' failed."
  * fixed 64bit issue in md5
  * fixed crash in mod_status
  * fixed duplicate headers in mod_proxy
  * fixed Content-Length in HEAD request in mod_proxy
  * fixed unsigned/signed comparisions
  * fixed streaming in mod_cgi
  * fixed possible overflow in password-salt handling
  * fixed server-traffic-limit if connection limit is not set
- reenabled FAM support. (using gamin)
* Tue Oct 11 2005 mrueckert@suse.de
- update to version 1.4.6
  * fixed compilation on MacOS X and cygwin
  * fixed compressed output if caching was disabled (seen in IE and Opera)
  * fixed range-request option
  * fixed mysql-vhost module (was broken in 1.4.5)
  * fixed false positive in the detection of case-insensitive FS
* Tue Oct  4 2005 mrueckert@suse.de
- update to version 1.4.5
